package com.srs.comprehensive.service.impl;

import java.util.List;

import com.srs.comprehensive.domain.CphStuEvaTaskList;
import com.srs.comprehensive.mapper.CphStuEvaTaskListMapper;
import com.srs.comprehensive.service.ICphStuEvaTaskListService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 综合素质评定任务记录Service业务层处理
 * 
 * @author srs
 * @date 2023-08-19
 */
@Service
public class CphStuEvaTaskListServiceImpl implements ICphStuEvaTaskListService
{
    @Autowired
    private CphStuEvaTaskListMapper cphStuEvaTaskListMapper;

    /**
     * 查询综合素质评定任务记录
     * 
     * @param id 综合素质评定任务记录主键
     * @return 综合素质评定任务记录
     */
    @Override
    public CphStuEvaTaskList selectCphStuEvaTaskListById(Long id)
    {
        return cphStuEvaTaskListMapper.selectCphStuEvaTaskListById(id);
    }

    /**
     * 查询综合素质评定任务记录列表
     * 
     * @param cphStuEvaTaskList 综合素质评定任务记录
     * @return 综合素质评定任务记录
     */
    @Override
    public List<CphStuEvaTaskList> selectCphStuEvaTaskListList(CphStuEvaTaskList cphStuEvaTaskList)
    {
        return cphStuEvaTaskListMapper.selectCphStuEvaTaskListList(cphStuEvaTaskList);
    }

    /**
     * 新增综合素质评定任务记录
     * 
     * @param cphStuEvaTaskList 综合素质评定任务记录
     * @return 结果
     */
    @Override
    public int insertCphStuEvaTaskList(CphStuEvaTaskList cphStuEvaTaskList)
    {
        return cphStuEvaTaskListMapper.insertCphStuEvaTaskList(cphStuEvaTaskList);
    }

    /**
     * 修改综合素质评定任务记录
     * 
     * @param cphStuEvaTaskList 综合素质评定任务记录
     * @return 结果
     */
    @Override
    public int updateCphStuEvaTaskList(CphStuEvaTaskList cphStuEvaTaskList)
    {
        return cphStuEvaTaskListMapper.updateCphStuEvaTaskList(cphStuEvaTaskList);
    }

    /**
     * 批量删除综合素质评定任务记录
     * 
     * @param ids 需要删除的综合素质评定任务记录主键
     * @return 结果
     */
    @Override
    public int deleteCphStuEvaTaskListByIds(Long[] ids)
    {
        return cphStuEvaTaskListMapper.deleteCphStuEvaTaskListByIds(ids);
    }

    /**
     * 删除综合素质评定任务记录信息
     * 
     * @param id 综合素质评定任务记录主键
     * @return 结果
     */
    @Override
    public int deleteCphStuEvaTaskListById(Long id)
    {
        return cphStuEvaTaskListMapper.deleteCphStuEvaTaskListById(id);
    }
}
